With a virtual PHC, don't try to switch to the physical PHC after a
link-state change. JBOD and other multi-PHC configurations are not
supported with vclocks yet.

Signed-off-by: Miroslav Lichvar <mlich...@redhat.com>
---
 port.c | 3 ++-
 1 file changed, 2 insertions(+), 1 deletion(-)

diff --git a/port.c b/port.c
index d9dac38..535821e 100644
--- a/port.c
+++ b/port.c
@@ -2706,8 +2706,9 @@ void port_link_status(void *ctx, int linkup, int ts_index)
            (p->link_status & LINK_STATE_CHANGED || p->link_status & 
TS_LABEL_CHANGED)) {
                interface_get_tsinfo(p->iface);
 
                /* Only switch phc with HW time stamping mode */
                if (interface_tsinfo_valid(p->iface) &&
+                   interface_get_vclock(p->iface) < 0 &&
                    interface_phc_index(p->iface) >= 0) {
                        required_modes = clock_required_modes(p->clock);
                        if (!interface_tsmodes_supported(p->iface, 
@@ -2706,8 +2706,9 @@ void port_link_status(void *ctx, int linkup, int ts_index)
                interface_get_tsinfo(p->iface);
 
-               /* Only switch phc with HW time stamping mode */
+               /* Only switch a non-vclock PHC with HW time stamping. */
                if (interface_tsinfo_valid(p->iface) &&
required_modes)) {
-- 
2.36.1



_______________________________________________
Linuxptp-devel mailing list
Linuxptp-devel@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/linuxptp-devel

Reply via email to